"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var date_fns_1 = require("date-fns");
var ner_1 = require("../../ner");
var ner = new ner_1.NER();
test('NER shoudl understand simple named days', function () {
    var today = date_fns_1.startOfDay(new Date());
    var dates = ner.recognize('will be in Dallas tomorrow');
    expect(dates).toMatchObject([date_fns_1.addDays(today, 1)]);
});
test('NER should understand simple dates', function () {
    var dates = ner.recognize('will be in Dallas 5/15/18');
    expect(dates).toMatchObject([date_fns_1.parse('2018-05-15')]);
});
test('NER shoudl understand simple enumeration', function () {
    var today = date_fns_1.startOfDay(new Date());
    var dates = ner.recognize('will be in Dallas today and tomorrow');
    expect(dates).toMatchObject([today, date_fns_1.addDays(today, 1)]);
});
test('NER should understand simple range', function () {
    var year = date_fns_1.getYear(new Date());
    var dates = ner.recognize('traveling from 5/15 till 5/17');
    expect(dates).toMatchObject([year + "-05-15", year + "-05-16", year + "-05-17"].map(function (str) { return date_fns_1.parse(str); }));
});
test('NER should be able to attach tokens', function () {
    var today = date_fns_1.startOfDay(new Date());
    var dates = ner.recognize('in Dubai next week tuesday');
    expect(dates).toMatchObject([date_fns_1.setDay(date_fns_1.addWeeks(today, 1), 2)]);
});
test('NER should be able to attach tokens over enumeration split', function () {
    var today = date_fns_1.startOfDay(new Date());
    var dates = ner.recognize('in Dubai next week tuesday and wednesday');
    expect(dates).toMatchObject([
        date_fns_1.setDay(date_fns_1.addWeeks(today, 1), 2),
        date_fns_1.setDay(date_fns_1.addWeeks(today, 1), 3)
    ]);
});
['I am out 5/5, 5/7, and 5/8', 'in NYC May 5th, 7th, and 8th'].forEach(function (utterance) {
    return test('NER should properly understand enumeration via a comma', function () {
        var year = date_fns_1.getYear(new Date());
        var dates = ner.recognize(utterance);
        expect(dates).toMatchObject([year + "-05-05", year + "-05-07", year + "-05-08"].map(function (str) {
            return date_fns_1.parse(str);
        }));
    });
});
test('NER shoudl udnerstand a range expressed in relative terms', function () {
    var today = date_fns_1.startOfDay(new Date());
    var dates = ner.recognize('last week Thursday till this week Tuesday');
    var start = date_fns_1.setDay(date_fns_1.addWeeks(today, -1), 4);
    var end = date_fns_1.setDay(today, 2);
    expect(dates).toMatchObject(date_fns_1.eachDay(start, end));
});
test('NER shoudl understand spelled out dates', function () {
    var year = date_fns_1.getYear(new Date());
    var dates = ner.recognize('will be in London from june third till june sixth');
    expect(dates).toMatchObject(date_fns_1.eachDay(date_fns_1.parse(year + "-06-03"), date_fns_1.parse(year + "-06-06")));
});
test('NER should understand a range with flipped date expressions', function () {
    var year = date_fns_1.getYear(new Date());
    var dates = ner.recognize('3rd of March and April 5th');
    expect(dates).toMatchObject([year + "-03-03", year + "-04-05"].map(function (str) { return date_fns_1.parse(str); }));
});
test('NER should prioritize closest direction expression', function () {
    var base = date_fns_1.addWeeks(date_fns_1.startOfDay(new Date()), -1);
    var dates = ner.recognize('I was in SFO this past Tue and Wed');
    expect(dates).toMatchObject([date_fns_1.setDay(base, 2), date_fns_1.setDay(base, 3)]);
});
test('NER should understand year directions', function () {
    var year = date_fns_1.getYear(new Date()) - 1;
    var dates = ner.recognize('I did not go anywhere last year december fifteenth');
    expect(dates).toMatchObject([date_fns_1.parse(year + "-12-15")]);
});
test('NER should understand formal date formats', function () {
    var year = date_fns_1.getYear(new Date());
    var dates = ner.recognize('I am in Dallas on Friday, June 29');
    // In reality, the comma is ignored
    // Friday is a token on its own and it has nothing (no direction) to attach to.
    // So Friday ends up being ignored and 29 will attach to June and compute a date
    // ToDo: do we need matchers and extractors for long formatted dates?
    expect(dates).toMatchObject([date_fns_1.parse(year + "-06-29")]);
});
//# sourceMappingURL=ner.test.js.map